@@ -2,10 +2,12 @@ __author__ = "Kura"
 __copyright__ = "None"
 __credits__ = ["Kura", ]
 __license__ = "BSD 3-Clause"
-__version__ = "1.3.1"
+__version__ = "1.3.2"
 __maintainer__ = "Kura"
 __email__ = "kura@kura.io"
-__status__ = "Development"
+__status__ = "Beta"
 
 __pname__ = "blackhole"
 __desc__ = "blackhole.io MTA"
+
+__fullname__ = "%s %s (%s)" % (__pname__, __version__, __status__)
\ No newline at end of file
