@@ -3,6 +3,8 @@ import ssl
 
 from tornado.options import options
 
+from blackhole.log import log
+
 
 sslkwargs = {
     'do_handshake_on_connect': False,
@@ -16,10 +18,15 @@ sslkwargs = {
 
 
 class BlackholeSSLException(Exception):
+	"""A simple Exception class"""
 	pass
 
 
 def verify_ssl_opts():
+	"""
+	Verify our SSL configuration variables are
+	correctly set-up.
+	"""
 	if not options.ssl_key or not options.ssl_cert:
 		raise BlackholeSSLException("You need to set an SSL certificate and SSL key")
 	if not os.path.exists(options.ssl_cert):
